@@ -4,8 +4,12 @@ use insta::assert_csv_snapshot;
 use insta::assert_ron_snapshot;
 #[cfg(feature = "toml")]
 use insta::assert_toml_snapshot;
-use insta::{assert_debug_snapshot, assert_json_snapshot, assert_snapshot, assert_yaml_snapshot};
-use serde::Serialize;
+#[cfg(feature = "yaml")]
+use insta::assert_yaml_snapshot;
+#[cfg(feature = "json")]
+use insta::{assert_compact_json_snapshot, assert_json_snapshot};
+
+use insta::{assert_compact_debug_snapshot, assert_debug_snapshot, assert_snapshot};
 use std::thread;
 
 #[test]
@@ -21,14 +25,16 @@ fn test_simple() {
 }
 
 #[test]
-fn test_single_line() {
-    assert_snapshot!("Testing", @"Testing");
+fn test_trailing_commas() {
+    assert_snapshot!(
+        "Testing",
+        @"Testing",
+    );
 }
 
 #[test]
-fn test_unnamed_single_line() {
-    assert_snapshot!("Testing");
-    assert_snapshot!("Testing-2");
+fn test_single_line() {
+    assert_snapshot!("Testing", @"Testing");
 }
 
 // We used to use the thread name for snapshot name detection.  This is unreliable
@@ -50,17 +56,18 @@ fn test_unnamed_thread_single_line() {
 #[test]
 fn test_newline() {
     // https://github.com/mitsuhiko/insta/issues/39
-    assert_snapshot!("\n", @"
-");
+    assert_snapshot!("\n", @r###"
+
+    "###);
 }
 
 #[cfg(feature = "csv")]
 #[test]
 fn test_csv_inline() {
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct Email(String);
 
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct User {
         id: u32,
         username: String,
@@ -80,10 +87,10 @@ fn test_csv_inline() {
 #[cfg(feature = "csv")]
 #[test]
 fn test_csv_inline_multiple_values() {
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct Email(String);
 
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct User {
         id: u32,
         username: String,
@@ -111,10 +118,10 @@ fn test_csv_inline_multiple_values() {
 #[cfg(feature = "ron")]
 #[test]
 fn test_ron_inline() {
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct Email(String);
 
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct User {
         id: u32,
         username: String,
@@ -137,10 +144,10 @@ fn test_ron_inline() {
 #[cfg(feature = "toml")]
 #[test]
 fn test_toml_inline() {
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct Email(String);
 
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct User {
         id: u32,
         username: String,
@@ -158,6 +165,7 @@ fn test_toml_inline() {
     "###);
 }
 
+#[cfg(feature = "json")]
 #[test]
 fn test_json_inline() {
     assert_json_snapshot!(vec!["foo", "bar"], @r###"
@@ -168,9 +176,10 @@ fn test_json_inline() {
     "###);
 }
 
+#[cfg(feature = "yaml")]
 #[test]
 fn test_yaml_inline() {
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct User {
         id: u32,
         username: String,
@@ -182,17 +191,16 @@ fn test_yaml_inline() {
         username: "peter-pan".into(),
         email: "peterpan@wonderland.invalid".into()
     }, @r###"
-    ---
     id: 42
     username: peter-pan
     email: peterpan@wonderland.invalid
     "###);
 }
 
-#[cfg(feature = "redactions")]
+#[cfg(all(feature = "redactions", feature = "yaml"))]
 #[test]
 fn test_yaml_inline_redacted() {
-    #[derive(Serialize)]
+    #[derive(serde::Serialize)]
     pub struct User {
         id: u32,
         username: String,
@@ -206,7 +214,6 @@ fn test_yaml_inline_redacted() {
     }, {
         ".id" => "[user-id]"
     }, @r###"
-    ---
     id: "[user-id]"
     username: peter-pan
     email: peterpan@wonderland.invalid
@@ -228,3 +235,72 @@ fn test_multiline_with_empty_lines() {
     # alternative
     "###);
 }
+
+#[cfg(feature = "json")]
+#[test]
+fn test_compact_json() {
+    assert_compact_json_snapshot!((1..30).collect::<Vec<_>>(), @"[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29]");
+    assert_compact_json_snapshot!((1..34).collect::<Vec<_>>(), @r###"
+    [
+      1,
+      2,
+      3,
+      4,
+      5,
+      6,
+      7,
+      8,
+      9,
+      10,
+      11,
+      12,
+      13,
+      14,
+      15,
+      16,
+      17,
+      18,
+      19,
+      20,
+      21,
+      22,
+      23,
+      24,
+      25,
+      26,
+      27,
+      28,
+      29,
+      30,
+      31,
+      32,
+      33
+    ]
+    "###);
+}
+
+#[test]
+fn test_compact_debug() {
+    assert_compact_debug_snapshot!((1..30).collect::<Vec<_>>(), @"[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29]");
+    assert_compact_debug_snapshot!((1..34).collect::<Vec<_>>(), @"[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33]");
+}
+
+#[test]
+#[should_panic = "Insta does not allow inline snapshot assertions in loops"]
+fn test_inline_test_in_loop() {
+    for i in 0..10 {
+        assert_snapshot!(i.to_string(), @"0");
+    }
+}
+
+#[test]
+fn test_inline_snapshot_whitespace() {
+    assert_snapshot!("\n\nfoo\n\n    bar\n\n", @r###"
+
+
+    foo
+
+        bar
+
+    "###);
+}
